<?php

/**
 * Affiche des informations sur l'article courant
 *
 * syntaxe 1 : {up jcontent-info=nom_info}
 * syntaxe 2 : {up jcontent_info}&lt;b&gt;une info :&lt;/b&gt; ##nom_info##{/up jcontent_info}
 * syntaxe 3 : {up jcontent_info | template=[b]une info :[/b] ##nom_info##}
 *
 * Les mots-clés :
 * ##id## ##title## ##subtitle##
 * ##image## ##image-src## ##image-alt## ##image-legend##
 * ##image-full## ##image-full-src## ##image-full-alt## ##image-full-legend##
 * ##date-crea## ##crea_by## ##date-modif## ##modif_by##
 * ##url-a## ##url-b## ##url-c##
 * ##date-publish## ##date-unpublish##
 * ##note## ##cat## ##catid## ##featured## ##hits## ##tags## ##author##
 *
 * @author   LOMART
 * @version  UP-2.5
 * @license   <a href="http://www.gnu.org/licenses/gpl-3.0.html" target="_blank">GNU/GPLv3</a>
 * @tags    Joomla
 */
defined('_JEXEC') or die;

class jcontent_info extends upAction {

    function init() {
        // charger les ressources communes à toutes les instances de l'action
        return true;
    }

    function run() {
        // lien vers la page de demo (vide=page sur le site de UP)
        $this->set_demopage();

        $options_def = array(
            __class__ => '', // le nom d'un élément ou rien
            'template' => '##content##', // modèle de mise en page. Si vide le modèle est le contenu. BBCode accepté
            'tag' => '_div', // balise pour le bloc d'un article. _div = div si class ou style, sinon rien. = 0=jamais
            'style' => '', // classes et styles inline pour un article
            'class' => '', // classe(s) pour un article (obsoléte)
            'date-format' => '%e %B %Y', // format pour les dates
            'date-locale' => '', // localisation pour les dates. Par défaut, celle du navigateur client.
            'featured-html' => '[b class="t-gris"]&#x2605;[/b], [b class="t-jauneFonce"]&#x2605;[/b]',
            'tags-list-prefix' => '', // texte avant les autres eventuels tags
            'tags-list-style' => 'badge;margin-right:4px', // classe ou style affecte a une balise span par mot-cle
            'tags-list-separator' => ' ', // separateur entre mots-cles
            'id' => '',
            'css-head' => '', // code CSS dans le head
        );


        // ======> fusion et controle des options
        $options = $this->ctrl_options($options_def);
        // ======> verif template (modèle de mise en page)
        // en priorité : le champ demande comme argument principal
        // en second : le template entre shortcode
        // l'option template
        if ($options[__class__]) {
            $tmpl = '##' . $options[__class__] . '##';
        } elseif ($this->content) {
            $tmpl = $this->content;
        } else {
            $tmpl = $this->get_bbcode($options['template'], false);
        }
        if (!$tmpl) {
            $this->msg_error(JText::_('Aucun contenu ni template'));
            return false;
        }

        if (isset($this->article->catid)) {
            $item = $this->article;
        } else {
            // appel d'un module : catégorie courante pour la page
            $app = JFactory::getApplication();
            $artid = $app->input->get('id', 0);
            // ---
            $j = new JVersion();
            $version = substr($j->getShortVersion(), 0, 1);
            if ($version == "4") { // Joomla 4.0
                $model = new ArticlesModel(array('ignore_request' => true));
            } else { // Joomla 3.x
                JLoader::register('ContentModelArticles', JPATH_SITE . '/components/com_content/models/articles.php');
                $model = JModelLegacy::getInstance('Articles', 'ContentModel', array('ignore_request' => true));
            }
            // ---
            $appParams = $app->getParams();
            $model->setState('params', $appParams);

            $model->setState('filter.article_id', $artid);

            $items = $model->getItems();
            if (count($items) == 0)
                return '';
            $item = $items[0];
        }

        // ======> Style général et par article
        $main_attr['id'] = $options['id'];
        $this->get_attr_style($tmpl_attr, $options['class'], $options['style']);

        // format date
        $this->set_locale($options['date-locale']);

        // css-head
        $this->load_css_head($options['css-head']);

        // ======> mise en forme résultat
        // --- le titre et sous titre
        $title = $item->title;
        $subtitle = '';
        if (stripos($tmpl, '##subtitle##') !== false) {
            $title = strstr($item->title . '~', '~', true);
            $subtitle = trim(substr(strstr($item->title, '~'), 1));
        }

        // ==== les remplacements
        // === ID
        $tmpl = str_ireplace('##id##', $item->id, $tmpl);
        // === TITLE & SUBTITLE
        $tmpl = str_ireplace('##title##', $title, $tmpl);
        $tmpl = str_ireplace('##subtitle##', $subtitle, $tmpl);
        // === CAT
        $tmpl = str_ireplace('##cat##', $item->category_title, $tmpl);
        $tmpl = str_ireplace('##catid##', $item->catid, $tmpl);
        // === NOTE
        if (stripos($tmpl, '##note##') !== false) {
            $db = JFactory::getDbo();
            $query = $db->getQuery(true);
            $query->select('note')
                    ->from('#__content')
                    ->where('id = ' . $item->id)
            ;
            $db->setQuery($query);
            $result = $db->loadResult();
            $tmpl = str_ireplace('##note##', $result, $tmpl);
        }
        // === DATE & AUTHOR
        $tmpl = str_ireplace('##date-crea##', utf8_encode(strftime($options['date-format'], strtotime($item->created))), $tmpl);
        $tmpl = str_ireplace('##crea_by##', JFactory::getUser($item->created_by)->get('name'), $tmpl);
        $tmpl = str_ireplace('##date-modif##', utf8_encode(strftime($options['date-format'], strtotime($item->modified))), $tmpl);
        $tmpl = str_ireplace('##modif_by##', JFactory::getUser($item->modified_by)->get('name'), $tmpl);
        $tmpl = str_ireplace('##author##', $item->author, $tmpl);
        // === DATE PUBLICATION
        $tmpl = str_ireplace('##date-publish##', utf8_encode(strftime($options['date-format'], strtotime($item->publish_up))), $tmpl);
        $tmpl = str_ireplace('##date-unpublish##', utf8_encode(strftime($options['date-format'], strtotime($item->publish_down))), $tmpl);
        // === TAGS
        if (stripos($tmpl, '##tags##') !== false) {
            $this->get_attr_style($tags_list_attr, $options['tags-list-style']);
            $db = JFactory::getDbo();
            $query = $db->getQuery(true);
            $query->select('t.title')
                    ->from('#__tags as t')
                    ->innerJoin('#__contentitem_tag_map as m on t.id = m.tag_id')
                    ->where('m.content_item_id = ' . $item->id . ' AND m.type_alias like "%article%"')
            ;
            $db->setQuery($query);
            $listTags = $db->loadObjectList();
            $tmpTags = (empty($listTags)) ? '' : $options['tags-list-prefix'];
            $tmpTag = array();
            foreach ($listTags as $tag) {
                if ($options['tags-list-style'] != '') {
                    $tmpTag[] = $this->set_attr_tag('span', $tags_list_attr, $tag->title);
                } else {
                    $tmpTag[] = $tag->title;
                }
            }
            $tmpl = str_ireplace('##tags##', implode($options['tags-list-separator'], $tmpTag), $tmpl);
        }

        // === en vedette
        if (stripos($tmpl, '##featured##') !== false) {
            $tmp = $this->get_bbcode($options['featured-html']);
            $tmp = explode(',', $tmp);
            $tmpl = str_ireplace('##featured##', $tmp[$item->featured], $tmpl);
        }
        // === HITS
        $tmpl = str_ireplace('##hits##', $item->hits, $tmpl);

        // === IMAGES
        if (stripos($tmpl, '##image') !== false) {
            $images = json_decode($item->images, true);
            foreach (array('image_intro' => 'image', 'image_fulltext' => 'image-full') AS $key => $keyword) {
                $img_src = $images[$key];
                $img_alt = $images[$key . '_alt'];
                if (empty($img_alt))
                    $img_alt = $this->link_humanize($img_src);
                $img_legend = $images[$key . '_caption'];
                $img = ($img_src) ? '<img src="' . $img_src . '" alt="' . $img_alt . '">' : '';
                $tmpl = str_ireplace('##' . $keyword . '##', $img, $tmpl);
                $tmpl = str_ireplace('##' . $keyword . '-src##', $img_src, $tmpl);
                $tmpl = str_ireplace('##' . $keyword . '-alt##', $img_alt, $tmpl);
                $tmpl = str_ireplace('##' . $keyword . '-legend##', $img_legend, $tmpl);
            }
        }

        // === URL
        if (stripos($tmpl, '##url-') !== false) {
            $urls = json_decode($item->urls, true);
            foreach (array('a', 'b', 'c') AS $key) {
                $attr = array();
                $url = '';
                $attr['href'] = $urls['url' . $key];
                $url_text = $urls['url' . $key . 'text'];
                if (empty($url_text))
                    $url_text = $attr['href'];
                if (!empty($attr['href'])) {
                    switch ($urls['target' . $key]) {
                        case 1 : // new
                            $attr['target'] = '_blank';
                            $attr['rel'] = "nofollow noopener noreferrer";
                            break;
                        case 2 : // popup
                            $attr['onclick'] = "window.open(this.href, 'targetWindow', 'toolbar=no,location=no,status=no,menubar=no,scrollbars=yes,resizable=yes,width=600,height=600'); return false;";
                            $attr['rel'] = "noopener noreferrer";
                            break;
                        case 3 : // modal
                            $attr['target'] = '_blank';
                            $attr['class'] = 'modal';
                            $attr['rel'] = "{handler: 'iframe', size: {x:600, y:600}} noopener noreferrer";
                            break;
                        default :
                            $attr['target'] = '_self';
                            $attr['rel'] = "nofollow";
                            break;
                    }
                    $url = $this->set_attr_tag('a', $attr, $url_text);
                }
                $tmpl = str_ireplace('##url-' . $key . '##', $url, $tmpl);
            }
        }

        // --- fin article
        $html = $this->set_attr_tag($options['tag'], $tmpl_attr, $tmpl);

        return $html;
    }

// run
}

// class





